aboutsummaryrefslogtreecommitdiff
path: root/zenserver/config.h
diff options
context:
space:
mode:
authorStefan Boberg <[email protected]>2021-09-15 10:04:50 +0200
committerStefan Boberg <[email protected]>2021-09-15 10:04:50 +0200
commitb5d89b30f29f12c14e5968a68118519118135fea (patch)
tree49c4f657d8839b7a120ec6b6dacefbfea38d9c8d /zenserver/config.h
parentUpdated function service to new package management API (diff)
downloadzen-b5d89b30f29f12c14e5968a68118519118135fea.tar.xz
zen-b5d89b30f29f12c14e5968a68118519118135fea.zip
Added options for indicating a server is running in "dedicated" mode
I.e running on a host to serve *remote* clients
Diffstat (limited to 'zenserver/config.h')
-rw-r--r--zenserver/config.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/zenserver/config.h b/zenserver/config.h
index 92b7c9e31..80ec86905 100644
--- a/zenserver/config.h
+++ b/zenserver/config.h
@@ -7,13 +7,14 @@
struct ZenServerOptions
{
- bool IsDebug = false;
- bool IsTest = false;
- int BasePort = 1337; // Service listen port (used for both UDP and TCP)
- int OwnerPid = 0; // Parent process id (zero for standalone)
- std::string ChildId; // Id assigned by parent process (used for lifetime management)
- std::string LogId; // Id for tagging log output
- std::filesystem::path DataDir; // Root directory for state (used for testing)
+ bool IsDebug = false;
+ bool IsTest = false;
+ bool IsDedicated = false; // Indicates a dedicated/shared instance, with larger resource requirements
+ int BasePort = 1337; // Service listen port (used for both UDP and TCP)
+ int OwnerPid = 0; // Parent process id (zero for standalone)
+ std::string ChildId; // Id assigned by parent process (used for lifetime management)
+ std::string LogId; // Id for tagging log output
+ std::filesystem::path DataDir; // Root directory for state (used for testing)
};
struct ZenUpstreamJupiterConfig